@@ -1,8 +1,10 @@
 import re
+import string
 
 from typing import Pattern
 
 from faker.providers.automotive import calculate_vin_str_weight
+from faker.providers.automotive.de_AT import Provider as DeAtAutomotiveProvider
 from faker.providers.automotive.de_DE import Provider as DeDeAutomotiveProvider
 from faker.providers.automotive.es_ES import Provider as EsEsAutomotiveProvider
 from faker.providers.automotive.ro_RO import Provider as RoRoAutomotiveProvider
@@ -37,6 +39,8 @@ class _SimpleAutomotiveTestMixin:
             checksum = (front_part_weight + rear_part_weight) % 11
             checksum_str = "X" if checksum == 10 else str(checksum)
             assert vin_number[8] == checksum_str
+            for char in vin_number[13:]:
+                assert char in string.digits
 
 
 class TestArBh(_SimpleAutomotiveTestMixin):
@@ -51,37 +55,20 @@ class TestAzAz(_SimpleAutomotiveTestMixin):
     license_plate_pattern = re.compile(r"\d{2}-[A-Z]{2}-\d{3}")
 
 
-class TestSkSk(_SimpleAutomotiveTestMixin):
-    """Test sk_SK automotive provider methods"""
+class TestDeAt(_SimpleAutomotiveTestMixin):
+    """Test de_AT automotive provider methods"""
 
-    license_plate_pattern: Pattern = re.compile(r"(?P<prefix>[A-Z]{2})\d{3}[A-Z]{2}")
+    license_plate_pattern: Pattern = re.compile(r"(?P<prefix>[A-Z]{1,2})-[1-9]{1}[0-9]{0,4} [A-Z]{1,3}")
 
     def perform_extra_checks(self, license_plate, match):
-        assert match.group("prefix") in SkSkAutomotiveProvider.license_plate_prefix
+        assert match.group("prefix") in DeAtAutomotiveProvider.license_plate_prefix
+        assert len(license_plate) in (8, 9)
 
 
-class TestPtBr(_SimpleAutomotiveTestMixin):
-    """Test pt_BR automotive provider methods"""
+class TestDeCh(_SimpleAutomotiveTestMixin):
+    """Test de_CH automotive provider methods"""
 
-    license_plate_pattern: Pattern = re.compile(r"[A-Z]{3}-\d{1}[A-Z]{1}\d{2}")
-
-
-class TestPtPt(_SimpleAutomotiveTestMixin):
-    """Test pt_PT automotive provider methods"""
-
-    license_plate_pattern: Pattern = re.compile(
-        r"\d{2}-\d{2}-[A-Z]{2}|" r"\d{2}-[A-Z]{2}-\d{2}|" r"[A-Z]{2}-\d{2}-\d{2}|" r"[A-Z]{2}-\d{2}-[A-Z]{2}",
-    )
-
-
-class TestHeIl(_SimpleAutomotiveTestMixin):
-    license_plate_pattern: Pattern = re.compile(r"(\d{3}-\d{2}-\d{3})|(\d{2}-\d{3}-\d{2})")
-
-
-class TestHuHu(_SimpleAutomotiveTestMixin):
-    """Test hu_HU automotive provider methods"""
-
-    license_plate_pattern: Pattern = re.compile(r"[A-Z]{3}-\d{3}")
+    license_plate_pattern: Pattern = re.compile(r"[A-Z]{2}-\d{1,3}\s?\d{0,3}")
 
 
 class TestDeDe(_SimpleAutomotiveTestMixin):
@@ -96,18 +83,10 @@ class TestDeDe(_SimpleAutomotiveTestMixin):
         assert match.group("prefix") in DeDeAutomotiveProvider.license_plate_prefix
 
 
-class TestSvSe(_SimpleAutomotiveTestMixin):
-    """Test sv_SE automotive provider methods"""
+class TestElGr(_SimpleAutomotiveTestMixin):
+    """Test el_GR automotive provider methods"""
 
-    license_plate_pattern: Pattern = re.compile(r"[A-Z]{3} \d{2}[\dA-Z]")
-
-
-class TestPlPl:
-    def test_License_plate(self, faker, num_samples):
-        pattern: Pattern = re.compile(r"{patterns}".format(patterns="|".join(faker.license_plate_regex_formats())))
-        for _ in range(num_samples):
-            plate = faker.license_plate()
-            assert pattern.fullmatch(plate)
+    license_plate_pattern = re.compile(r"^(?P<prefix>[A-Z]{2,3}) \d{4}$")
 
 
 class TestEnPh(_SimpleAutomotiveTestMixin):
@@ -131,62 +110,6 @@ class TestEnPh(_SimpleAutomotiveTestMixin):
             assert int(protocol_plate) != 15 and 1 <= int(protocol_plate) <= 17
 
 
-class TestFilPh(TestEnPh):
-    """Test fil_PH automotive provider methods"""
-
-    pass
-
-
-class TestTlPh(TestEnPh):
-    """Test tl_PH automotive provider methods"""
-
-    pass
-
-
-class TestRuRu(_SimpleAutomotiveTestMixin):
-    """Test ru_RU automotive provider methods"""
-
-    _plate_letters = "".join(RuRuAutomotiveProvider.license_plate_letters)
-    license_plate_pattern: Pattern = re.compile(
-        r"(?:"
-        r"(?P<private_plate_prefix>[{0}]\d\d\d[{0}][{0}])|"
-        r"(?P<public_transport_plate_prefix>[{0}][{0}]\d\d\d)|"
-        r"(?P<trailer_plate_prefix>[{0}][{0}]\d\d\d\d)|"
-        r"(?P<police_plate_prefix>[{0}]\d\d\d\d)|"
-        r"(?P<military_plate_prefix>\d\d\d\d[{0}][{0}])|"
-        r"(?P<plate_number_special>00\dCD\d|00\dD\d\d\d|00\dT\d\d\d)"
-        r") (?P<plate_suffix>.*)".format(_plate_letters),
-    )
-
-    def perform_extra_checks(self, license_plate, match):
-        plate_suffix = match.group("plate_suffix")
-        assert plate_suffix in RuRuAutomotiveProvider.license_plate_suffix
-
-    def test_vehicle_category(self, faker, num_samples):
-        for _ in range(num_samples):
-            vehicle_category = faker.vehicle_category()
-            assert isinstance(vehicle_category, str)
-            assert vehicle_category in RuRuAutomotiveProvider.vehicle_categories
-
-
-class TestFrFr(_SimpleAutomotiveTestMixin):
-    """Test fr_FR automotive provider methods"""
-
-    license_plate_pattern: Pattern = re.compile(r"\d{3}-[A-Z]{3}-\d{2}|[A-Z]{2}-\d{3}-[A-Z]{2}")
-
-
-class TestItIt(_SimpleAutomotiveTestMixin):
-    """Test it_IT automotive provider methods"""
-
-    license_plate_pattern: Pattern = re.compile(r"[A-Z]{2}\d{3}[A-Z]{2}")
-
-
-class TestNoNo(_SimpleAutomotiveTestMixin):
-    """Test no_NO automotive provider methods"""
-
-    license_plate_pattern: Pattern = re.compile(r"[A-Z]{2} \d{5}")
-
-
 class TestEsCo(_SimpleAutomotiveTestMixin):
     """Test es_CO automotive provider methods"""
 
@@ -227,48 +150,62 @@ class TestEsEs:
             assert self.new_format_pattern.match(plate) or self.old_format_pattern.match(plate)
 
 
-class TestThTh(_SimpleAutomotiveTestMixin):
-    """Test th_TH automotive provider methods"""
+class TestFiFi(_SimpleAutomotiveTestMixin):
+    """Test fi_FI automotive provider methods"""
+
+    license_plate_pattern: Pattern = re.compile(r"[A-Z]{3}-\d{3}")
+
+
+class TestFilPh(TestEnPh):
+    """Test fil_PH automotive provider methods"""
+
+    pass
+
+
+class TestFrFr(_SimpleAutomotiveTestMixin):
+    """Test fr_FR automotive provider methods"""
+
+    license_plate_pattern: Pattern = re.compile(r"\d{3}-[A-Z]{3}-\d{2}|[A-Z]{2}-\d{3}-[A-Z]{2}")
+
+
+class TestHeIl(_SimpleAutomotiveTestMixin):
+    license_plate_pattern: Pattern = re.compile(r"(\d{3}-\d{2}-\d{3})|(\d{2}-\d{3}-\d{2})")
+
+
+class TestHuHu(_SimpleAutomotiveTestMixin):
+    """Test hu_HU automotive provider methods"""
+
+    license_plate_pattern: Pattern = re.compile(r"[A-Z]{3}-\d{3}")
+
+
+class TestItIt(_SimpleAutomotiveTestMixin):
+    """Test it_IT automotive provider methods"""
+
+    license_plate_pattern: Pattern = re.compile(r"[A-Z]{2}\d{3}[A-Z]{2}")
+
+
+class TestJaJp(_SimpleAutomotiveTestMixin):
+    """Test ja_JP automotive provider methods"""
 
     license_plate_pattern: Pattern = re.compile(
-        r"(\d [ก-ฮ]{2} \d{1,4})|"  # car
-        r"([ก-ฮ]{2} \d{1,4})|"  # car
-        r"([ก-ฮ]{3} \d{1,3})|"  # motorcycle
-        r"(\d{2}-\d{4})",  # truck
+        r"^(?:品川|足立|練馬|横浜|川崎|名古屋|大阪|神戸|福岡|札幌|尾張小牧|伊勢志摩) "
+        r"\d{2,3} "
+        r"(?:あ|い|う|え|か|き|く|け|こ|さ|す|せ|そ|た|ち|つ|て|と|な|に|ぬ|ね|の|は|ひ|ふ|ほ|"
+        r"ま|み|む|め|も|や|ゆ|よ|ら|り|る|れ|ろ|わ|を) "
+        r"(?:\d{2}-\d{2}|・{1,3}\d{1,3})$"
     )
 
 
-class TestTrTr(_SimpleAutomotiveTestMixin):
-    """Test tr_TR automotive provider methods"""
-
+class TestKoKr(_SimpleAutomotiveTestMixin):
     license_plate_pattern: Pattern = re.compile(
-        r"\d{2} [A-Z] \d{4}|"
-        r"\d{2} [A-Z] \d{5}|"
-        r"\d{2} [A-Z]{2} \d{3}|"
-        r"\d{2} [A-Z]{2} \d{4}|"
-        r"\d{2} [A-Z]{3} \d{2}|"
-        r"\d{2} [A-Z]{3} \d{3}",
+        r"^\d{2,3}[가나다라마거너더러머버서어저고노도로모보소오조구누두루무부수우주]\d{4}$"
     )
 
-    def perform_extra_checks(self, license_plate, match):
-        [city_code, letters, _] = license_plate.split(" ")
-        assert int(city_code) in range(1, 82)
-        assert all(letter in TrTrAutomotiveProvider.ascii_uppercase_turkish for letter in letters)
 
+class TestNlBe(_SimpleAutomotiveTestMixin):
+    """Test nl_BE automotive provider methods"""
 
-class TestRoRo(_SimpleAutomotiveTestMixin):
-    """Test ro_RO automotive provider methods"""
-
-    license_plate_pattern: Pattern = re.compile(r"(?P<prefix>[A-Z]{1,2})-\d{2,3}-[A-Z]{3}")
-
-    def perform_extra_checks(self, license_plate, match):
-        assert match.group("prefix") in RoRoAutomotiveProvider.license_plate_prefix
-
-
-class TestElGr(_SimpleAutomotiveTestMixin):
-    """Test el_GR automotive provider methods"""
-
-    license_plate_pattern = re.compile(r"^(?P<prefix>[A-Z]{2,3}) \d{4}$")
+    license_plate_pattern: Pattern = re.compile(r"(\d{3}-[A-Z]{3})|" r"([A-Z]{3}-\d{3})|" r"([1-2]-[A-Z]{3}-\d{3})")
 
 
 class TestNlNl(_SimpleAutomotiveTestMixin):
@@ -303,16 +240,76 @@ class TestNlNl(_SimpleAutomotiveTestMixin):
             assert self.license_plate_motorbike_pattern.match(plate)
 
 
-class TestViVn(_SimpleAutomotiveTestMixin):
-    """Test vi_VN automotive provider methods"""
+class TestNoNo(_SimpleAutomotiveTestMixin):
+    """Test no_NO automotive provider methods"""
 
-    license_plate_pattern: Pattern = re.compile(r"\d{2}[ABCDĐEFGHKLMNPSTUVXYZ]-\d{5}")
+    license_plate_pattern: Pattern = re.compile(r"[A-Z]{2} \d{5}")
 
 
-class TestFiFi(_SimpleAutomotiveTestMixin):
-    """Test fi_FI automotive provider methods"""
+class TestPlPl:
+    def test_License_plate(self, faker, num_samples):
+        pattern: Pattern = re.compile(r"{patterns}".format(patterns="|".join(faker.license_plate_regex_formats())))
+        for _ in range(num_samples):
+            plate = faker.license_plate()
+            assert pattern.fullmatch(plate)
 
-    license_plate_pattern: Pattern = re.compile(r"[A-Z]{3}-\d{3}")
+
+class TestPtBr(_SimpleAutomotiveTestMixin):
+    """Test pt_BR automotive provider methods"""
+
+    license_plate_pattern: Pattern = re.compile(r"[A-Z]{3}-\d{1}[A-Z]{1}\d{2}")
+
+
+class TestPtPt(_SimpleAutomotiveTestMixin):
+    """Test pt_PT automotive provider methods"""
+
+    license_plate_pattern: Pattern = re.compile(
+        r"\d{2}-\d{2}-[A-Z]{2}|" r"\d{2}-[A-Z]{2}-\d{2}|" r"[A-Z]{2}-\d{2}-\d{2}|" r"[A-Z]{2}-\d{2}-[A-Z]{2}",
+    )
+
+
+class TestRoRo(_SimpleAutomotiveTestMixin):
+    """Test ro_RO automotive provider methods"""
+
+    license_plate_pattern: Pattern = re.compile(r"(?P<prefix>[A-Z]{1,2})-\d{2,3}-[A-Z]{3}")
+
+    def perform_extra_checks(self, license_plate, match):
+        assert match.group("prefix") in RoRoAutomotiveProvider.license_plate_prefix
+
+
+class TestRuRu(_SimpleAutomotiveTestMixin):
+    """Test ru_RU automotive provider methods"""
+
+    _plate_letters = "".join(RuRuAutomotiveProvider.license_plate_letters)
+    license_plate_pattern: Pattern = re.compile(
+        r"(?:"
+        r"(?P<private_plate_prefix>[{0}]\d\d\d[{0}][{0}])|"
+        r"(?P<public_transport_plate_prefix>[{0}][{0}]\d\d\d)|"
+        r"(?P<trailer_plate_prefix>[{0}][{0}]\d\d\d\d)|"
+        r"(?P<police_plate_prefix>[{0}]\d\d\d\d)|"
+        r"(?P<military_plate_prefix>\d\d\d\d[{0}][{0}])|"
+        r"(?P<plate_number_special>00\dCD\d|00\dD\d\d\d|00\dT\d\d\d)"
+        r") (?P<plate_suffix>.*)".format(_plate_letters),
+    )
+
+    def perform_extra_checks(self, license_plate, match):
+        plate_suffix = match.group("plate_suffix")
+        assert plate_suffix in RuRuAutomotiveProvider.license_plate_suffix
+
+    def test_vehicle_category(self, faker, num_samples):
+        for _ in range(num_samples):
+            vehicle_category = faker.vehicle_category()
+            assert isinstance(vehicle_category, str)
+            assert vehicle_category in RuRuAutomotiveProvider.vehicle_categories
+
+
+class TestSkSk(_SimpleAutomotiveTestMixin):
+    """Test sk_SK automotive provider methods"""
+
+    license_plate_pattern: Pattern = re.compile(r"(?P<prefix>[A-Z]{2})\d{3}[A-Z]{2}")
+
+    def perform_extra_checks(self, license_plate, match):
+        assert match.group("prefix") in SkSkAutomotiveProvider.license_plate_prefix
 
 
 class TestSqAl(_SimpleAutomotiveTestMixin):
@@ -321,36 +318,46 @@ class TestSqAl(_SimpleAutomotiveTestMixin):
     license_plate_pattern: Pattern = re.compile(r"[A-Z]{2} \d{3}[A-Z]{2}")
 
 
-class TestDeCh(_SimpleAutomotiveTestMixin):
-    """Test de_CH automotive provider methods"""
+class TestSvSe(_SimpleAutomotiveTestMixin):
+    """Test sv_SE automotive provider methods"""
 
-    license_plate_pattern: Pattern = re.compile(r"[A-Z]{2}-\d{1,3}\s?\d{0,3}")
+    license_plate_pattern: Pattern = re.compile(r"[A-Z]{3} \d{2}[\dA-Z]")
 
 
-class TestNlBe(_SimpleAutomotiveTestMixin):
-    """Test nl_BE automotive provider methods"""
-
-    license_plate_pattern: Pattern = re.compile(r"(\d{3}-[A-Z]{3})|" r"([A-Z]{3}-\d{3})|" r"([1-2]-[A-Z]{3}-\d{3})")
-
-
-class TestZhCn(_SimpleAutomotiveTestMixin):
-    """Test zh_CN automotive provider methods"""
+class TestThTh(_SimpleAutomotiveTestMixin):
+    """Test th_TH automotive provider methods"""
 
     license_plate_pattern: Pattern = re.compile(
-        r"^[京津冀晋蒙辽吉黑沪苏浙皖闽赣鲁豫鄂湘粤桂琼川贵云渝藏陕甘青宁新]{1}[A-Z]{1}-[A-Z0-9]{5}"
+        r"(\d [ก-ฮ]{2} \d{1,4})|"  # car
+        r"([ก-ฮ]{2} \d{1,4})|"  # car
+        r"([ก-ฮ]{3} \d{1,3})|"  # motorcycle
+        r"(\d{2}-\d{4})",  # truck
     )
 
 
-class TestZhTw(_SimpleAutomotiveTestMixin):
-    """Test zh_TW automotive provider methods"""
+class TestTlPh(TestEnPh):
+    """Test tl_PH automotive provider methods"""
+
+    pass
+
+
+class TestTrTr(_SimpleAutomotiveTestMixin):
+    """Test tr_TR automotive provider methods"""
 
     license_plate_pattern: Pattern = re.compile(
-        r"([A-Z]{2}-\d{4})|"  # prior 2012 v1
-        r"(\d{4}-[A-Z]{2})|"  # prior 2012 v2
-        r"([A-Z]{3}-\d{4})|"  # new format since 2014
-        r"([A-Z]{3}-\d{3})",  # commercial cars since 2012
+        r"\d{2} [A-Z] \d{4}|"
+        r"\d{2} [A-Z] \d{5}|"
+        r"\d{2} [A-Z]{2} \d{3}|"
+        r"\d{2} [A-Z]{2} \d{4}|"
+        r"\d{2} [A-Z]{3} \d{2}|"
+        r"\d{2} [A-Z]{3} \d{3}",
     )
 
+    def perform_extra_checks(self, license_plate, match):
+        [city_code, letters, _] = license_plate.split(" ")
+        assert int(city_code) in range(1, 82)
+        assert all(letter in TrTrAutomotiveProvider.ascii_uppercase_turkish for letter in letters)
+
 
 class TestUkUa(_SimpleAutomotiveTestMixin):
     license_plate_pattern: Pattern = re.compile(r"[A-Z]{2}\d{4}[A-Z]{2}")
@@ -382,3 +389,28 @@ class TestUkUa(_SimpleAutomotiveTestMixin):
 
     def test_region_code(self, faker):
         assert "14" == faker.plate_region_code(region_name="Lviv")
+
+
+class TestViVn(_SimpleAutomotiveTestMixin):
+    """Test vi_VN automotive provider methods"""
+
+    license_plate_pattern: Pattern = re.compile(r"\d{2}[ABCDĐEFGHKLMNPSTUVXYZ]-\d{5}")
+
+
+class TestZhCn(_SimpleAutomotiveTestMixin):
+    """Test zh_CN automotive provider methods"""
+
+    license_plate_pattern: Pattern = re.compile(
+        r"^[京津冀晋蒙辽吉黑沪苏浙皖闽赣鲁豫鄂湘粤桂琼川贵云渝藏陕甘青宁新]{1}[A-Z]{1}-[A-Z0-9]{5}"
+    )
+
+
+class TestZhTw(_SimpleAutomotiveTestMixin):
+    """Test zh_TW automotive provider methods"""
+
+    license_plate_pattern: Pattern = re.compile(
+        r"([A-Z]{2}-\d{4})|"  # prior 2012 v1
+        r"(\d{4}-[A-Z]{2})|"  # prior 2012 v2
+        r"([A-Z]{3}-\d{4})|"  # new format since 2014
+        r"([A-Z]{3}-\d{3})",  # commercial cars since 2012
+    )
