@@ -8,10 +8,14 @@ from faker import Faker
 from faker.providers.person.ar_AA import Provider as ArProvider
 from faker.providers.person.az_AZ import Provider as AzAzProvider
 from faker.providers.person.cs_CZ import Provider as CsCZProvider
+from faker.providers.person.de_AT import Provider as DeAtProvider
+from faker.providers.person.de_LI import Provider as DeLiProvider
 from faker.providers.person.en import Provider as EnProvider
 from faker.providers.person.en_GB import Provider as EnGBProvider
 from faker.providers.person.en_IE import Provider as EnIEProvider
 from faker.providers.person.en_IN import Provider as EnINProvider
+from faker.providers.person.en_KE import Provider as EnKEProvider
+from faker.providers.person.en_NG import Provider as EnNgProvider
 from faker.providers.person.en_PK import Provider as EnPKprovider
 from faker.providers.person.en_US import Provider as EnUSProvider
 from faker.providers.person.es import Provider as EsProvider
@@ -21,9 +25,12 @@ from faker.providers.person.fi_FI import Provider as FiProvider
 from faker.providers.person.fr_BE import Provider as FrBEProvider
 from faker.providers.person.ga_IE import Provider as GaIEProvider
 from faker.providers.person.gu_IN import Provider as GuINProvider
+from faker.providers.person.ha_NG import Provider as HaNgProvider
 from faker.providers.person.he_IL import Provider as HeILProvider
 from faker.providers.person.hi_IN import Provider as HiINProvider
 from faker.providers.person.hy_AM import Provider as HyAmProvider
+from faker.providers.person.ig_NG import Provider as IgNgProvider
+from faker.providers.person.is_IS import Provider as IsISProvider
 from faker.providers.person.lv_LV import Provider as LvProvider
 from faker.providers.person.ne_NP import Provider as NeProvider
 from faker.providers.person.nl_BE import Provider as NlBEProvider
@@ -210,6 +217,92 @@ class TestCsCZ(unittest.TestCase):
         assert last_name in CsCZProvider.last_names_female
 
 
+class TestDeAt(unittest.TestCase):
+    """Tests person in the de_AT locale"""
+
+    def setUp(self):
+        self.fake = Faker("de_AT")
+        Faker.seed(0)
+
+    def test_academic_prefix(self):
+        academic_prefix = self.fake.academic_prefix()
+        assert isinstance(academic_prefix, str)
+        assert academic_prefix in DeAtProvider.academic_prefixes
+
+    def test_academic_suffix(self):
+        academic_suffix = self.fake.academic_suffix()
+        assert isinstance(academic_suffix, str)
+        assert academic_suffix in DeAtProvider.academic_suffixes
+
+    def test_first_name(self):
+        first_name = self.fake.first_name()
+        assert isinstance(first_name, str)
+        assert first_name in DeAtProvider.first_names
+
+    def test_first_name_female(self):
+        name_female = self.fake.first_name_female()
+        assert isinstance(name_female, str)
+        assert name_female in DeAtProvider.first_names_female
+
+    def test_first_name_male(self):
+        name_male = self.fake.first_name_male()
+        assert isinstance(name_male, str)
+        assert name_male in DeAtProvider.first_names_male
+
+    def test_first_name_nonbinary(self):
+        name_nonbinary = self.fake.first_name_nonbinary()
+        assert isinstance(name_nonbinary, str)
+        assert name_nonbinary in DeAtProvider.first_names
+
+    def test_last_name(self):
+        last_name = self.fake.last_name()
+        assert isinstance(last_name, str)
+        assert last_name in DeAtProvider.last_names
+
+    def test_prefix(self):
+        prefix = self.fake.prefix()
+        assert isinstance(prefix, str)
+        assert prefix in DeAtProvider.prefixes
+
+    def test_prefix_female(self):
+        prefix_female = self.fake.prefix_female()
+        assert isinstance(prefix_female, str)
+        assert prefix_female in DeAtProvider.prefixes_female
+
+    def test_prefix_male(self):
+        prefix_male = self.fake.prefix_male()
+        assert isinstance(prefix_male, str)
+        assert prefix_male in DeAtProvider.prefixes_male
+
+    def test_prefix_nonbinary(self):
+        prefix_nonbinary = self.fake.prefix_nonbinary()
+        assert isinstance(prefix_nonbinary, str)
+        assert prefix_nonbinary in DeAtProvider.prefixes
+
+
+class TestDeLi(unittest.TestCase):
+    """Tests person in the de_LI locale"""
+
+    def setUp(self):
+        self.fake = Faker("de_LI")
+        Faker.seed(0)
+
+    def test_first_name(self):
+        first_name = self.fake.first_name()
+        assert isinstance(first_name, str)
+        assert first_name in DeLiProvider.first_names
+
+    def test_first_name_female(self):
+        name_female = self.fake.first_name_female()
+        assert isinstance(name_female, str)
+        assert name_female in DeLiProvider.first_names_female
+
+    def test_first_name_male(self):
+        name_male = self.fake.first_name_male()
+        assert isinstance(name_male, str)
+        assert name_male in DeLiProvider.first_names_male
+
+
 class TestEn(unittest.TestCase):
     """Tests person in the en locale"""
 
@@ -254,6 +347,54 @@ class TestEnGB(unittest.TestCase):
         return names[1]
 
 
+class TestEnNG(unittest.TestCase):
+    """Tests person in the en_NG (English - Nigeria) locale"""
+
+    def setUp(self):
+        self.fake = Faker("en_NG")
+        Faker.seed(0)
+
+    def test_name(self):
+        name = self.fake.name()
+        self.assertIsInstance(name, str)
+
+        name = self.fake.name_female()
+        self.assertIsInstance(name, str)
+
+        name = self.fake.name_male()
+        self.assertIsInstance(name, str)
+
+    def test_first_name(self):
+        name = self.fake.first_name()
+        self.assertIsInstance(name, str)
+        assert name in EnNgProvider.first_names
+
+        name = self.fake.first_name_female()
+        self.assertIsInstance(name, str)
+        assert name in EnNgProvider.first_names
+        assert name in EnNgProvider.first_names_female
+
+        name = self.fake.first_name_male()
+        self.assertIsInstance(name, str)
+        assert name in EnNgProvider.first_names
+        assert name in EnNgProvider.first_names_male
+
+    def test_last_name(self):
+        assert hasattr(EnNgProvider, "last_names")
+
+        name = self.fake.last_name()
+        self.assertIsInstance(name, str)
+        assert name in EnNgProvider.last_names
+
+        name = self.fake.last_name_female()
+        self.assertIsInstance(name, str)
+        assert name in EnNgProvider.last_names
+
+        name = self.fake.last_name_male()
+        self.assertIsInstance(name, str)
+        assert name in EnNgProvider.last_names
+
+
 class TestEnIE(unittest.TestCase):
     """Tests person in the en-IE locale"""
 
@@ -346,6 +487,7 @@ class TestEnPk(unittest.TestCase):
     def test_last_name(self):
         """Test if the last name is from the predefined list."""
         last_name = self.fake.last_name()
+        self.assertGreater(len(last_name), 1, "Last name should have more than 1 character.")
         self.assertIn(last_name, EnPKprovider.last_names)
 
     def test_full_name(self):
@@ -360,8 +502,20 @@ class TestEnPk(unittest.TestCase):
         name = self.fake.name()
         name_parts = name.split()
         self.assertGreaterEqual(len(name_parts), 2, "Full name should have at least a first and last name.")
-        self.assertIn(name_parts[0], EnPKprovider.first_names)
-        self.assertIn(name_parts[-1], EnPKprovider.last_names)
+        if len(name_parts) == 2:
+            self.assertIn(name_parts[0], EnPKprovider.first_names)
+            self.assertIn(name_parts[-1], EnPKprovider.last_names)
+        elif len(name_parts) == 4:
+            self.assertIn(name_parts[:2], EnPKprovider.first_names)
+            self.assertIn(name_parts[2:], EnPKprovider.last_names)
+        elif len(name_parts) == 3:
+            assert (
+                " ".join(name_parts[:2]) in EnPKprovider.first_names
+                and " ".join(name_parts[2]) in EnPKprovider.last_names
+            ) or (
+                " ".join(name_parts[:1]) in EnPKprovider.first_names
+                and " ".join(name_parts[1:]) in EnPKprovider.last_names
+            ), "Either first two name parts should be in first names, or last two should be in last names."
 
 
 class TestEnUS(unittest.TestCase):
@@ -707,19 +861,6 @@ class TestGuIN(unittest.TestCase):
     def test_name(self):
         name = self.fake.name().split()
         assert all(isinstance(n, str) for n in name)
-        if len(name) == 3:
-            assert all(
-                [
-                    name[0] in GuINProvider.prefixes,
-                    name[1] in GuINProvider.first_names,
-                    name[2] in GuINProvider.last_names,
-                ]
-            )
-        else:
-            assert name[0] in GuINProvider.first_names
-            assert name[-1] in GuINProvider.last_names
-
-    """Verify that gender specific prefixes are set correctly"""
 
     def test_prefix(self):
         prefix = self.fake.prefix()
@@ -737,6 +878,54 @@ class TestGuIN(unittest.TestCase):
         assert prefix in GuINProvider.prefixes_male
 
 
+class TestHaNG(unittest.TestCase):
+    """Tests person in the ha_NG (Hausa - Nigeria) locale"""
+
+    def setUp(self):
+        self.fake = Faker("ha_NG")
+        Faker.seed(0)
+
+    def test_name(self):
+        name = self.fake.name()
+        self.assertIsInstance(name, str)
+
+        name = self.fake.name_female()
+        self.assertIsInstance(name, str)
+
+        name = self.fake.name_male()
+        self.assertIsInstance(name, str)
+
+    def test_first_name(self):
+        name = self.fake.first_name()
+        self.assertIsInstance(name, str)
+        assert name in HaNgProvider.first_names
+
+        name = self.fake.first_name_female()
+        self.assertIsInstance(name, str)
+        assert name in HaNgProvider.first_names
+        assert name in HaNgProvider.first_names_female
+
+        name = self.fake.first_name_male()
+        self.assertIsInstance(name, str)
+        assert name in HaNgProvider.first_names
+        assert name in HaNgProvider.first_names_male
+
+    def test_last_name(self):
+        assert hasattr(HaNgProvider, "last_names")
+
+        name = self.fake.last_name()
+        self.assertIsInstance(name, str)
+        assert name in HaNgProvider.last_names
+
+        name = self.fake.last_name_female()
+        self.assertIsInstance(name, str)
+        assert name in HaNgProvider.last_names
+
+        name = self.fake.last_name_male()
+        self.assertIsInstance(name, str)
+        assert name in HaNgProvider.last_names
+
+
 class TestHeIL(unittest.TestCase):
     """Tests person in the he_IL locale."""
 
@@ -870,6 +1059,104 @@ class TestHyAM(unittest.TestCase):
         assert name in HyAmProvider.last_names
 
 
+class TestIgNG(unittest.TestCase):
+    """Tests person in the ig_NG (Igbo - Nigeria) locale"""
+
+    def setUp(self):
+        self.fake = Faker("ig_NG")
+        Faker.seed(0)
+
+    def test_name(self):
+        name = self.fake.name()
+        self.assertIsInstance(name, str)
+
+        name = self.fake.name_female()
+        self.assertIsInstance(name, str)
+
+        name = self.fake.name_male()
+        self.assertIsInstance(name, str)
+
+    def test_first_name(self):
+        name = self.fake.first_name()
+        self.assertIsInstance(name, str)
+        assert name in IgNgProvider.first_names
+
+        name = self.fake.first_name_female()
+        self.assertIsInstance(name, str)
+        assert name in IgNgProvider.first_names
+        assert name in IgNgProvider.first_names_female
+
+        name = self.fake.first_name_male()
+        self.assertIsInstance(name, str)
+        assert name in IgNgProvider.first_names
+        assert name in IgNgProvider.first_names_male
+
+    def test_last_name(self):
+        assert hasattr(IgNgProvider, "last_names")
+
+        name = self.fake.last_name()
+        self.assertIsInstance(name, str)
+        assert name in IgNgProvider.last_names
+
+        name = self.fake.last_name_female()
+        self.assertIsInstance(name, str)
+        assert name in IgNgProvider.last_names
+
+        name = self.fake.last_name_male()
+        self.assertIsInstance(name, str)
+        assert name in IgNgProvider.last_names
+
+
+class TestIsIS(unittest.TestCase):
+    """Tests person in the is_IS locale"""
+
+    def setUp(self):
+        self.fake = Faker("is_IS")
+        Faker.seed(0)
+
+    def test_first_name(self):
+        name = self.fake.first_name()
+        self.assertIsInstance(name, str)
+        assert name in IsISProvider.first_names
+
+    def test_first_name_male(self):
+        name = self.fake.first_name_male()
+        self.assertIsInstance(name, str)
+        assert name in IsISProvider.first_names_male
+
+    def test_first_name_female(self):
+        name = self.fake.first_name_female()
+        self.assertIsInstance(name, str)
+        assert name in IsISProvider.first_names_female
+
+    def test_last_name(self):
+        last_name = self.fake.last_name()
+        self.assertIsInstance(last_name, str)
+        assert last_name.endswith("son") or last_name.endswith("dóttir")
+        suffix = "son" if last_name.endswith("son") else "dóttir"
+        last_name_wo_suffix = last_name.rsplit(suffix, maxsplit=1)[0]
+        assert last_name_wo_suffix in IsISProvider.last_names_without_suffix
+
+    def test_last_name_male(self):
+        last_name = self.fake.last_name_male()
+        self.assertIsInstance(last_name, str)
+        assert last_name.endswith("son")
+        last_name_wo_suffix = last_name.rsplit("son", maxsplit=1)[0]
+        assert last_name_wo_suffix in IsISProvider.last_names_without_suffix
+
+    def test_last_name_female(self):
+        last_name = self.fake.last_name_female()
+        self.assertIsInstance(last_name, str)
+        assert last_name.endswith("dóttir")
+        last_name_wo_suffix = last_name.rsplit("dóttir", maxsplit=1)[0]
+        assert last_name_wo_suffix in IsISProvider.last_names_without_suffix
+
+    def test_middle_name(self):
+        middle_name = self.fake.middle_name()
+        self.assertIsInstance(middle_name, str)
+        assert middle_name in IsISProvider.middle_names
+
+
 class TestJaJP(unittest.TestCase):
     """Tests person in the ja_JP locale"""
 
@@ -1595,7 +1882,7 @@ class TestYoNG(unittest.TestCase):
 
     def test_last_name(self):
         """
-        Test the generation of Zulu last names.
+        Test the generation of yoruba last names.
         """
         # There's no gender-specific last name in Zulu.
         self.assertTrue(hasattr(YoNGProvider, "last_names_male"))
@@ -1621,7 +1908,7 @@ class TestYoNG(unittest.TestCase):
 
     def test_first_name(self):
         """
-        Test the generation of Zulu first names.
+        Test the generation of yoruba first names.
         """
         # General first name.
         name = self.fake.first_name()
@@ -1642,7 +1929,7 @@ class TestYoNG(unittest.TestCase):
 
     def test_full_name(self):
         """
-        Test the generation of full Zulu names.
+        Test the generation of full yoruba names.
         """
         # Full name.
         name = self.fake.name()
@@ -1769,13 +2056,13 @@ class TestZhTW(unittest.TestCase):
         self.assertIsInstance(name, str)
         assert name in ZhTWProvider.last_names
 
-        # Females last name.
+        # Females last name. (no gender-specific)
         name = self.fake.last_name_female()
         assert name
         self.assertIsInstance(name, str)
         assert name in ZhTWProvider.last_names
 
-        # Male last name.
+        # Male last name. (no gender-specific)
         name = self.fake.last_name_male()
         assert name
         self.assertIsInstance(name, str)
@@ -1826,10 +2113,36 @@ class TestZhTW(unittest.TestCase):
         name = self.fake.romanized_name()
         assert name
         self.assertIsInstance(name, str)
-        first_romanized_name, last_romanized_name = name.split(" ")
+        last_romanized_name, first_romanized_name = name.split(" ")  # 'WANG SHU-FEN' or 'SHU-FEN, WANG' are both okay.
+        # first_romanized_name, last_romanized_name = name.split(" ")
         assert first_romanized_name in ZhTWProvider.first_romanized_names
         assert last_romanized_name in ZhTWProvider.last_romanized_names
 
+    def test_person(self):
+        name = self.fake.name()
+        assert name
+        assert isinstance(name, str)
+
+        first_name = self.fake.first_name()
+        assert first_name
+        assert isinstance(first_name, str)
+
+        last_name = self.fake.last_name()
+        assert last_name
+        assert isinstance(last_name, str)
+
+        romanized_name = self.fake.romanized_name()
+        assert romanized_name
+        assert isinstance(romanized_name, str)
+
+        first_romanized_name = self.fake.first_romanized_name()
+        assert first_romanized_name
+        assert isinstance(first_romanized_name, str)
+
+        last_romanized_name = self.fake.last_romanized_name()
+        assert last_romanized_name
+        assert isinstance(last_romanized_name, str)
+
 
 class TestZuZa(unittest.TestCase):
     def setUp(self):
@@ -1937,5 +2250,65 @@ class TestUzUz(unittest.TestCase):
             assert res in self.provider.last_names_female
 
 
+class TestEnKE(unittest.TestCase):
+    """Test en_KE person provider"""
+
+    def setUp(self):
+        self.fake = Faker("en_KE")
+        Faker.seed(0)
+        self.provider = EnKEProvider
+
+    def test_first_name(self):
+        # General first name
+        name = self.fake.first_name()
+        self.assertIsInstance(name, str)
+        self.assertIn(name, self.provider.first_names)
+
+    def test_first_name_female(self):
+        # Female first name
+        name = self.fake.first_name_female()
+        self.assertIsInstance(name, str)
+        self.assertIn(name, self.provider.first_names)
+        self.assertIn(name, self.provider.first_names_female)
+
+    def test_first_name_male(self):
+        # Male first name
+        name = self.fake.first_name_male()
+        self.assertIsInstance(name, str)
+        self.assertIn(name, self.provider.first_names)
+        self.assertIn(name, self.provider.first_names_male)
+
+    def test_last_name(self):
+        # General last name
+        name = self.fake.last_name()
+        self.assertIsInstance(name, str)
+        self.assertIn(name, self.provider.last_names)
+
+    def test_prefixes(self):
+        # Test male prefixes
+        prefix_m = self.fake.prefix_male()
+        self.assertIn(prefix_m, self.provider.prefixes_male)
+
+        # Test female prefixes
+        prefix_f = self.fake.prefix_female()
+        self.assertIn(prefix_f, self.provider.prefixes_female)
+
+    def test_name_formats(self):
+        # Test general name format
+        name = self.fake.name()
+        self.assertIsInstance(name, str)
+        self.assertGreaterEqual(len(name.split()), 2)
+
+        # Test male name format
+        male_name = self.fake.name_male()
+        self.assertIsInstance(male_name, str)
+        self.assertGreaterEqual(len(male_name.split()), 2)
+
+        # Test female name format
+        female_name = self.fake.name_female()
+        self.assertIsInstance(female_name, str)
+        self.assertGreaterEqual(len(female_name.split()), 2)
+
+
 if __name__ == "__main__":
     unittest.main()
